﻿"""
メインプログラムです。
入力画面を表示します。
詳細は README.pdf を参照してください。

Copyright (C) 2024 UNION SYSTEM Inc.

"""

from tkinter import Tk
from tkinter import ttk
import tkinter
import cost_graph as cg
import tkinter.filedialog
import os


# [実行]ボタン
def btn_run_click() -> None:
    """
    [実行]ボタンをクリックした時の処理
    """
    # 選択された結果リストを生成
    lst_res: list = []
    int_index: int = 1
    for var in lst_var:
        if var.get():
            lst_res.append("結果" + str(int_index))
        int_index += 1

    # グラフ描画の開始
    cg.cost_graph(dat_path.get(), lst_res)


# [...]（参照）ボタン
def btn_ref_click() -> None:
    """
    [...]（参照）ボタンをクリックしたときの処理
    フォルダ選択ダイアログを開く
    """
    str_dir: str = os.path.abspath(os.path.dirname(__file__))
    str_folder_name: str = tkinter.filedialog.askdirectory(initialdir=str_dir)
    dat_path_txt.insert(tkinter.END, str_folder_name)


# [閉じる]ボタン
def btn_close_click() -> None:
    """
    [閉じる]ボタンをクリックしたときの処理
    """
    exit()


# メイン処理
# 入力が面を表示します。
if __name__ == "__main__":

    # ウィンドウを作成
    root = Tk()

    # ウィンドウサイズを指定
    root.geometry("430x180")

    # ウィンドウタイトルを指定
    root.title("積算グラフ比較")

    # ウィンドウ枠を固定
    root.resizable()

    frame1 = ttk.Frame(root, padding=(20))
    frame1.grid()

    # 物件のパス
    label1 = ttk.Label(frame1, text="SS7物件データ", padding=(5, 2))
    label1.grid(row=0, column=0, sticky=tkinter.E)

    dat_path: tkinter.StringVar = tkinter.StringVar()
    dat_path_txt: ttk.Entry = ttk.Entry(frame1, textvariable=dat_path, width=40)
    dat_path_txt.grid(row=0, column=1)

    lst_var: list = []
    lst_che: list = []
    # 「結果1」チェックボックス
    lst_var.append(tkinter.BooleanVar())
    lst_che.append(ttk.Checkbutton(text="結果1", variable=lst_var[0]))
    lst_che[0].place(x=40, y=50)

    # 「結果2」チェックボックス
    lst_var.append(tkinter.BooleanVar())
    lst_che.append(ttk.Checkbutton(text="結果2", variable=lst_var[1]))
    lst_che[1].place(x=40, y=70)

    # 「結果3」チェックボックス
    lst_var.append(tkinter.BooleanVar())
    lst_che.append(ttk.Checkbutton(text="結果3", variable=lst_var[2]))
    lst_che[2].place(x=40, y=90)

    # 「結果4」チェックボックス
    lst_var.append(tkinter.BooleanVar())
    lst_che.append(ttk.Checkbutton(text="結果4", variable=lst_var[3]))
    lst_che[3].place(x=40, y=110)

    # 「結果5」チェックボックス
    lst_var.append(tkinter.BooleanVar())
    lst_che.append(ttk.Checkbutton(text="結果5", variable=lst_var[4]))
    lst_che[4].place(x=40, y=130)

    # 「実行」ボタン
    btn_run = ttk.Button(
        text="実行", width=15, padding=[10, 20, 10, 20], command=btn_run_click
    )
    btn_run.place(x=280, y=50)

    # 「・・・」ボタン
    btn_ref = ttk.Button(text="...", width=6, command=btn_ref_click)
    btn_ref.place(x=350, y=20)

    # 「閉じる」ボタン
    btn_close = ttk.Button(text="閉じる", width=18, command=btn_close_click)
    btn_close.place(x=280, y=120)

    # ウィンドウ表示継続
    root.mainloop()
