﻿"""
「コンクリート」「型枠」「鉄筋」「鉄骨」のグラフを描画します。
詳細は README.pdf を参照してください。

Copyright (C) 2024 UNION SYSTEM Inc.

"""

import matplotlib.pyplot as plt
import japanize_matplotlib
import pandas as pd

RC_ITEM: list = [
    "基礎",
    "基礎梁",
    "柱",
    "大梁",
    "片持梁",
    "小梁",
    "床",
    "耐震壁",
    "雑壁",
    "ﾊﾟﾗﾍﾟｯﾄ",
    "その他",
]
S_ITEM: list = ["柱", "大梁", "片持梁", "小梁", "鉛直ﾌﾞﾚｰｽ", "その他"]

# グラフの描画関数
japanize_matplotlib


def draw_graph(df: pd.DataFrame, ax: plt.Axes, graph_name: str, labels: list) -> None:
    """
    材料のグラフ描画

    Args:
        df (pd.DataFrame): 材料データ
        ax (plt.Axes): 描画領域
        graph_name (str): グラフの名前
        labels (list): 凡例
    """
    ax.set_title(graph_name, loc="center")
    if len(df) > 0:
        for i in range(len(df)):
            if i == 0:
                ax.bar(df.columns, df.iloc[i], label=labels[i], width=0.5)
                val_tmp = df.iloc[i].copy()
            else:
                ax.bar(
                    df.columns,
                    df.iloc[i],
                    label=labels[i],
                    bottom=val_tmp,
                    width=0.5,
                )
                val_tmp += df.iloc[i]
        handles, grh_labels = ax.get_legend_handles_labels()  # 凡例の情報を取得
        ax.legend(
            handles=handles[::-1],
            labels=grh_labels[::-1],
            bbox_to_anchor=(1.05, 1),
            loc="upper left",
            borderaxespad=0,
        )  # 判例を逆順に表示


def plot_graph(
    df_con: pd.DataFrame,
    df_kata: pd.DataFrame,
    df_rein: pd.DataFrame,
    df_steel: pd.DataFrame,
    lst_res: list,
) -> None:
    """
    グラフの描画関数

    Args:
        df_con (pd.DataFrame): コンクリートデータ
        df_kata (pd.DataFrame): 型枠データ
        df_rein (pd.DataFrame): 鉄筋データ
        df_steel (pd.DataFrame): 鉄骨データ
        lst_res (list): _description_
    """

    # 描画領域
    fig: plt.Figure = plt.figure(figsize=(10, 7))
    fig.subplots_adjust(right=0.8, wspace=0.7)
    ax_con: plt.Axes = fig.add_subplot(2, 2, 1)
    ax_kata: plt.Axes = fig.add_subplot(2, 2, 2)
    ax_rein: plt.Axes = fig.add_subplot(2, 2, 3)
    ax_steel: plt.Axes = fig.add_subplot(2, 2, 4)

    # 「コンクリート」のグラフ
    draw_graph(df_con, ax_con, "コンクリート体積[m3]", RC_ITEM)

    # 「型枠」のグラフ
    draw_graph(df_kata, ax_kata, "型枠面積[m2]", RC_ITEM)

    # 「鉄筋」のグラフ
    draw_graph(df_rein, ax_rein, "鉄筋重量[t]", RC_ITEM)

    # 「鉄骨」のグラフ
    draw_graph(df_steel, ax_steel, "鉄骨重量[t]", S_ITEM)

    plt.show()
