﻿"""
『SS7』のCSVファイルを読み込みます。
詳細は README.pdf を参照してください。

Copyright (C) 2024 UNION SYSTEM Inc.

"""


import csv


# 引数の解析
def parsing_arguments(str_val: str, str_fixed: str, int_index: int) -> tuple:
    """
    引数を解析して、項目名、項目の索引位置、索引位置を返します。

    Args:
        str_val (str): 項目名
        str_fixed (str): 項目名（固定部分）
        int_index (int): 項目の索引位置

    Returns:
        tuple: 項目名、項目の索引位置、索引位置
    """
    int_val_index: int = -1
    if len(str_val) > 0:
        str_val = str_fixed + str_val
        int_val_index = int_index
        int_index += 1
    return str_val, int_val_index, int_index


# CSVファイルの内容を読み込む
def get_data(
    str_csv_path: str,  # ファイルを含むパス
    str_name: str,  # 出力項目名
    str_tab: str = "",  # タブ名
    str_group: str = "",  # グループ名
    str_case: str = "",  # ケース名
) -> list:
    """
    CSVファイルの内容を読み込む

    Args:
        str_csv_path (str): CSVファイルのパス
        str_name (str): 項目名
        str_tab (str): タブ名
        str_group (str): グループ名
        str_case (str): ケース名

    Returns:
        list: CSVファイルから取得したデータ
    """

    # csvファイルからデータの取得
    with open(str_csv_path, encoding="shift-jis") as f:
        data = csv.reader(f)
        lndat = [line for line in data]

    # 初期値のセット
    bln_data_flag: bool = False  # データ読み込みフラグ
    int_index: int = 0  # 引数のIndex

    # 引数の解析
    # name
    str_name, int_name_index, int_index = parsing_arguments(
        str_name, "name=", int_index
    )
    # tab
    str_tab, int_tab_index, int_index = parsing_arguments(str_tab, "tab=", int_index)
    # group
    str_group, int_group_index, int_index = parsing_arguments(
        str_group, "group=", int_index
    )
    # case
    str_case, int_case_index, int_index = parsing_arguments(
        str_case, "case=", int_index
    )

    # データの解析
    lst_ret: list = []
    for l_dat in lndat:
        # テーブルの先頭行の確認
        if not bln_data_flag:
            if len(l_dat) < int_index:  # テーブル先頭行のデータ数を確認
                continue  # 少ない場合は次の行へ移る
            # 項目名、タブ、グループ、ケースの確認
            if len(str_name) > 0 and l_dat[int_name_index] != str_name:
                continue
            if len(str_tab) > 0 and l_dat[int_tab_index] != str_tab:
                continue
            if len(str_group) > 0 and l_dat[int_group_index] != str_group:
                continue
            if len(str_case) > 0 and l_dat[int_case_index] != str_case:
                continue
            bln_data_flag = True

        # 行のデータが空白となるまで行をリストに登録する。
        if len(l_dat) == 0:
            bln_data_flag = False
            continue
        lst_ret.append(l_dat)
    return lst_ret
