﻿"""
『Op.Python実行』により、積算の結果を結果CSVファイルに出力します。
詳細は README.pdf を参照してください。

Copyright (C) 2024 UNION SYSTEM Inc.

"""

from Python import Ss7Python as cmd


# 積算の結果作成
def make_cost_result_csv(
    str_path: str, str_csv_path: str, str_res: str, int_flag: int
) -> bool:
    """
    積算の結果を結果CSVファイルに出力します。

    Args:
        str_path (str): 物件フォルダのパス
        str_csv_path (str): CSVファイルのパス
        str_res (str): 結果名
        int_flag (int): 1:コンクリート，型枠，鉄筋、2:鉄骨

    Returns:
        bool: True:結果生成した　False:結果生成できなかった
    """
    cmd.Init()
    cmd.Start("1.1.1.19", 1)  # 1:ログファイルをクリアする

    # 物件を開く
    dat: cmd.Ss7Data = cmd.Open(
        str_path, 1, 2
    )  # 1:変換して開く 2:バックアップは削除して物件データを開く
    if dat is not None:
        res_dat: cmd.Ss7ResultData = dat.GetResultData(str_res)
        if res_dat is not None:
            # 計算結果から入力データを復元
            dat.Restore(str_res)
            # 積算が計算済か確認
            if not dat.IsCalcEnd(str_res, "積算"):
                # 積算を計算する
                dat.Calculate(str_res, "積算")
                # エラー情報を取得する
                err: cmd.ErrorInfo = cmd.GetLastError()
                # 計算が失敗したとき、終了する
                if not err.IsOK():
                    cmd.End(2)  # 2:保存しないで終了
                    return False
                res_dat = dat.GetResultData(str_res)
            # 結果CSVファイルの生成
            if int_flag == 1:
                # コンクリート，型枠，鉄筋
                res_dat.ExportResultCsv(
                    "17.4.2.1.部位別集計表", str_csv_path, 1, 1, 1
                )  # 1:同一ファイルが存在する場合、上書きする 1:出力する際の記号を省略する 1:断面算定表は全部材出力
            if int_flag == 2:
                # 鉄骨
                res_dat.ExportResultCsv(
                    "17.4.3.1.部位別集計表", str_csv_path, 1, 1, 1
                )  # 1:同一ファイルが存在する場合、上書きする 1:出力する際の記号を省略する 1:断面算定表は全部材出力
            # エラー情報を取得する
            err = cmd.GetLastError()
            if not err.IsOK():
                cmd.End(2)  # 2:保存しないで終了
                return False
        else:
            cmd.End(2)  # 2:保存しないで終了
            return False
        dat.Close(2)  # 2=保存しない
    cmd.End(2)  # 2:保存しないで終了
    return True
